<?php

declare(strict_types=1);


namespace App\Exchanges\Kuna;


use App\Exchanges\MarketInterface;
use App\Utils\Money\Currency;
use App\Utils\Money\CurrencyPair;

class KunaMarket implements MarketInterface
{

    private KunaApiExecutor $apiExecutor;
    private CurrencyPair $currencyPair;
    private string $id;


    public static function createFromApiData(
        array $marketData,
        KunaApiExecutor $apiExecutor
    ): self
    {
        return new self(
            $apiExecutor,
            new CurrencyPair(
                new Currency($marketData['base_unit'], (int)$marketData['base_precision']),
                new Currency($marketData['quote_unit'], (int)$marketData['quote_precision']),
            ),
            $marketData['id']
        );
    }

    public function __construct(
        KunaApiExecutor $apiExecutor,
        CurrencyPair $currencyPair,
        string $id
    )
    {
        $this->apiExecutor = $apiExecutor;
        $this->currencyPair = $currencyPair;
        $this->id = $id;
    }

    public function getPair(): CurrencyPair
    {
        return $this->currencyPair;
    }
}